# Changelog

## [2.0.0a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/2.0.0a1) (2024-10-31)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/1.0.3...2.0.0a1)

**Breaking changes:**

- fix:duplicate\_handled\_message [\#262](https://github.com/OpenVoiceOS/OVOS-workshop/pull/262) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
